<?php

namespace Drupal\Tests\session_inspector\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Test the functionality of the session inspector module configuration form.
 *
 * @group session_inspector
 */
class SessionInspectorConfigTest extends BrowserTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = [
    'session_inspector',
    'session_inspector_plugins_test',
  ];

  /**
   * The theme to install as the default for testing.
   *
   * @var string
   */
  public $defaultTheme = 'stark';

  /**
   * Test that an anonymous user can't access the configuration form.
   */
  public function testAnonUserCanNotReachTheConfigForm() {
    $this->drupalGet('admin/config/people/session_inspector');
    $this->assertSession()->responseContains('Access denied');
  }

  /**
   * Test that a user can inspect and delete their own sessions.
   */
  public function testAdminUserCanEditConfig() {
    $user = $this->createUser(['administer session inspector configuration']);
    $this->drupalLogin($user);

    $this->drupalGet('admin/config/people/session_inspector');

    $input = [];
    $input['browser_format'] = 'testing';
    $input['hostname_format'] = 'testing';

    $this->submitForm($input, 'Save configuration');

    // Ensure that the configuration options are now set.
    $this->assertEquals('testing', $this->container->get('config.factory')->get('session_inspector.settings')->get('browser_format'));
    $this->assertEquals('testing', $this->container->get('config.factory')->get('session_inspector.settings')->get('hostname_format'));
  }

}
